@@ -366,7 +366,7 @@ class ClUpdateAction(Action):
               'message': __('Updating Kernel modules'),
               'method': 'Update.emerge("","@module-rebuild")',
               'condition': UpdateConditions.was_installed(
-                  'sys-kernel/.*source', EmergeMark.KernelModules),
+                  'sys-kernel/(calculate-sources|gentoo-kernel*)', EmergeMark.KernelModules),
               'decoration': 'Update.update_task("%s")' %
                             EmergeMark.KernelModules
              },
